#!/bin/bash
# epgscan.sh by Frank Jepsen
#
# Scans for EPG Data on first channels via svdrpsend.pl
#
# Add a call like this to the start of the runvdr script:
# /usr/share/vdr/epgscan.sh &
#
# You can test by adding any single parameter e.g. "test"
# By doing this only a scan is performed

CONFFILE="/etc/vdr/vdr-addon-hw-wakeup.conf"
VDRCONFFILE="/etc/vdr/setup.conf"
SVDRPSEND="/usr/share/vdr/svdrpsend.pl"
CHANNELCONF="/etc/vdr/channels.conf"
LOGFILE="/var/log/epgscan.log"

# read arguments from conf-file
if [ -e $CONFFILE ]; then
  echo "Using ConfFile $CONFFILE." > $LOGFILE
. $CONFFILE
else
  echo "ConfFile $CONFFILE not found. Using defaults." > $LOGFILE
fi

# Get old Channel
OldChannel=`cat $VDRCONFFILE | grep "^CurrentChannel" | awk -F= '{print$2}'`

[ -z "$EPG_MAX_CHANNEL" ]	&& export EPG_MAX_CHANNEL="50"
[ -z "$EPG_TIME_PER_CHANNEL" ]	&& export EPG_TIME_PER_CHANNEL="20"
[ -z "$EPG_STARTMIN" ]		&& export EPG_STARTMIN="5"
[ -z "$EPG_WAIT_BEFORE_START" ]	&& export EPG_WAIT_BEFORE_START="30"

# Testmode
if [ "$1" ]
then
  echo "Testmode" > $LOGFILE
  DAILY_TIMER_STD="0"
  DAILY_TIMER_MIN="0"
  TESTMODE="1"
fi

if [ -z $DAILY_TIMER_STD ] || [ -z $DAILY_TIMER_MIN ]
then
  echo "No Daily Timer specified." > $LOGFILE
else
  # only start within EPG_STARTMIN minutes after DAILYTIMER
  NOW=$((`date +%s`))
  DAILYTIMER=`expr $NOW / 86400 \* 86400 - 7200 + $DAILY_TIMER_STD \* 3600 + $DAILY_TIMER_MIN \* 60`
  if [ $TESTMODE ] || [ $NOW -gt $DAILYTIMER ]
  then
    DAILYTIMER=`expr $DAILYTIMER + $EPG_STARTMIN \* 60`
    if [ $TESTMODE ] || [ $DAILYTIMER -gt $NOW ]
    then
      # Let VDR start completely before starting to scan
      sleep $EPG_WAIT_BEFORE_START

      Channel="0"
      for Freq in `cat $CHANNELCONF | egrep -v -e "^:" | awk -F: '{print$2}' `
      do
        Channel=`expr $Channel + 1`
        echo Channel:$Channel Freq:$Freq > $LOGFILE
        if [ -z ${ScannedFreq[$Freq]} ]; then
          $SVDRPSEND CHAN $Channel > $LOGFILE
          ScannedFreq[$Freq]="1"
          sleep $EPG_TIME_PER_CHANNEL
        fi
        if [ $Channel -eq $EPG_MAX_CHANNEL ]; then
          break
        fi
      done

      # switch to previous channel
      $SVDRPSEND CHAN $OldChannel > $LOGFILE
      sleep 5

      # shutdown VDR
      if [ -z $TESTMODE ]
      then
        $SVDRPSEND HITK Power > $LOGFILE
      fi
    else
      echo "Not started in DailyTimer StartWindow" > $LOGFILE
    fi
  else
    echo "Not started in DailyTimer StartWindow" > $LOGFILE
  fi
fi
