#
# VDR shutdown hook for hw-wakeup - Frank Jepsen
# --------------------------------------------------
# inspired by shutdown hook for nvram-wakeup
# by Tobias Grimm
#
# This shutdown hook sets the wakeup time for the next timer using
# hw-wakeup. 
#


# read arguments for hw-wakeup from conf-file
if [ -e /etc/vdr/vdr-addon-hw-wakeup.conf ]
then
. /etc/vdr/vdr-addon-hw-wakeup.conf
fi

# Defaults:
[ -z "$ENABLED" ]           && export ENABLED="no"
[ -z "$WAKEUP_PORT" ]       && export WAKEUP_PORT="/dev/ttyS0"
[ -z "$KILL_LIRC" ]         && export KILL_LIRC="yes"
[ -z "$MIN_PRE_TIMER" ]     && export MIN_PRE_TIMER=5
[ -z "$MAX_POWEROFF_TIME" ] && export MAX_POWEROFF_TIME=0
[ -z "$MAX_TRY_AGAIN" ]     && export MAX_TRY_AGAIN=0

#For testing
#MAX_POWEROFF_TIME=60
#DAILY_TIMER_STD=4
#DAILY_TIMER_MIN=30
#KILL_LIRC="no"

# Const
NEVER=2147483647

if [ $MAX_TRY_AGAIN -gt 0 ]
then
  # another script wants to retry shutdown later
  logger -t vdr-addon-hw-wakeup "hw-wakeup not called - shutdown suspended by other script"
  EXITCODE=0
else
  if [ $ENABLED = "no" ]
  then
    # vdr-addon-hw-wakeup is disabled, so just exit
    logger -t vdr-addon-hw-wakeup "hw-wakeup functionality is disabled"
    EXITCODE=0
  else
    # calculate, at what time the machine should be powered on

    # VDR-Timer
    NOW=$((`date +%s`))
#    echo "NOW           " `date -d "1970-01-01 $NOW seconds UTC" "+%H:%M %d.%m.%Y"` $NOW
    if [ -z $1 ] || [ $1 -eq 0 ]
    then
      NEXTTIMER=$NEVER
    else
      NEXTTIMER=`expr $1 - $MIN_PRE_TIMER \* 60`
    fi
#    echo "TIMER         " `date -d "1970-01-01 $NEXTTIMER seconds UTC" "+%H:%M %d.%m.%Y"` $NEXTTIMER

    # Daily Timer
    if [ -z $DAILY_TIMER_STD ] || [ -z $DAILY_TIMER_MIN ]
    then
      NEXTDAILYTIMER=$NEVER
    else
      NEXTDAILYTIMER=`expr $NOW / 86400 \* 86400 - 7200 + $DAILY_TIMER_STD \* 3600 + $DAILY_TIMER_MIN \* 60`
      if [ $NOW -gt $NEXTDAILYTIMER ]
      then
        NEXTDAILYTIMER=`expr $NEXTDAILYTIMER + 86400`
      fi
    fi
#    echo "DAILYTIMER    " `date -d "1970-01-01 $NEXTDAILYTIMER seconds UTC" "+%H:%M %d.%m.%Y"` $NEXTDAILYTIMER

    # MaxPowerOff Time
    if [ $MAX_POWEROFF_TIME -eq 0 ]
    then
      WAKEUPTIME=$NEVER
      echo "1"
    else
      WAKEUPTIME=`expr $NOW + $MAX_POWEROFF_TIME \* 60`
      echo "2"
    fi
#    echo "MAXPOWEROFF   " `date -d "1970-01-01 $WAKEUPTIME seconds UTC" "+%H:%M %d.%m.%Y"` $WAKEUPTIME

    # Who comes first?
    if [ $WAKEUPTIME -gt $NEXTTIMER ] && [ $NEXTDAILYTIMER -gt $NEXTTIMER ]
    then
      WAKEUPTIME=$NEXTTIMER
    else
      if [ $WAKEUPTIME -gt $NEXTDAILYTIMER ]
      then
        WAKEUPTIME=$NEXTDAILYTIMER
      fi
    fi
#    echo "WAKEUPTIME    " `date -d "1970-01-01 $WAKEUPTIME seconds UTC" "+%H:%M %d.%m.%Y"` $WAKEUPTIME
    
    if [ $WAKEUPTIME -eq $NEVER ]
    then
      WAKEUPSTR="00000000"
    else
      WAKEUPSTR=`date -d "1970-01-01 $WAKEUPTIME seconds UTC" +%H%M%d%m`
    fi

    TIMESTR=`date +%H%M%d%m`

    logger -t vdr-addon-hw-wakeup "echo -n ATS00000000 > $WAKEUP_PORT"
    logger -t vdr-addon-hw-wakeup "echo -n ATS$WAKEUPSTR > $WAKEUP_PORT"
    logger -t vdr-addon-hw-wakeup "echo -n RTS$TIMESTR > $WAKEUP_PORT"

    if [ $KILL_LIRC = "yes" ]
    then
      logger -t vdr-addon-hw-wakeup "Shutting down LIRC"
      /etc/init.d/lirc stop
      setserial $WAKEUP_PORT uart 16550A
      sleep 1
    fi

    echo -n ATS00000000 > $WAKEUP_PORT
    sleep 1
    echo -n ATS$WAKEUPSTR > $WAKEUP_PORT
    sleep 1
    echo -n RTS$TIMESTR > $WAKEUP_PORT
    EXITCODE=0
  fi
fi
